@@ -1,5 +1,5 @@
 package Kx;
-
+$Kx::VERSION = '0.042';
 use 5.008;
 use strict;
 use warnings;
@@ -8,8 +8,6 @@ use POSIX ();
 
 my $DEBUG = 0;
 
-$Kx::VERSION = '0.040_001';
-
 my %NULL = (
     'symbol'   => '`',
     'short'    => "0Nh",
@@ -70,7 +68,7 @@ XSLoader::load( 'Kx', $Kx::VERSION );
 
 =head1 NAME
 
-Kx - Perl extension for Kdb+ http://kx.com
+Kx - Perl extension for Kdb+ L<http://kx.com>
 
 =head1 SYNOPSIS
 
@@ -1017,7 +1015,7 @@ To create Kdb+ atoms locally in RAM use the following calls.
     $d=$k->float(20.44);       # should look closer to 20.44 as a float
     $d=$k->sym('mysymbol');    # A Kdb+ symbol
     $d=$k->date(2007,4,22);    # integer encoded date year, month, day
-    $d=$k->dt(time());         # Kdb+ datetime from epoch
+    $d=$k->dt(time());         # Kdb+ datetime from Unix epoch
     $d=$k->tm(100);            # Time type in milliseconds
 
 These allow for fine grained control over the 'type' of K object you
@@ -1042,16 +1040,16 @@ retuned from a date() call it is in epoch seconds.
     my $date = $k->date(2007,4,22);
     print scalar localtime($date->val),"\n";
 
-Further more KDB+ Datetimes are held as a C double in memory. The
+Further more, KDB+ Datetimes are held as a C double in memory. The
 integral part is the number of days since 1/1/2000 and the fractional
 part is the fraction of the day. You have some control over how datetimes
 are returned from KDB+ back into Perl data structures. By default a
-conversion to epoch seconds will be made. You can also get epoch seconds
+conversion to Unix epoch seconds will be made. You can also get epoch seconds
 with milliseconds and you can also turn off conversion all together.
 
-    Kx::__Z2epoch(0);   # turn off epoch conversion
-    Kx::__Z2epoch(1);   # turn on epoch conversion (default)
-    Kx::__Z2epoch(2);   # turn on epoch conversion plus milliseconds
+    Kx::__Z2epoch(0);   # turn off Kdb+ to Unix epoch conversion
+    Kx::__Z2epoch(1);   # turn on Kdb+ to Unix epoch conversion (default)
+    Kx::__Z2epoch(2);   # turn on Kdb+ to Unix epoch conversion plus millisecs
 
 These have immediate effects on how datetimes are converted into Perl
 data structures. These do not effect what is held in RAM after a call to
@@ -1192,6 +1190,8 @@ sub kval {
 
 =head2 LISTS
 
+=head3 Simple Lists
+
 These list functions create in memory local lists outside of any 'q'
 running process. These will allow you to create very large simple lists
 without blowing out all your memory.
@@ -1288,8 +1288,7 @@ DBs).  Here is an example:
     eval $arrsym;
     print $VAR1->{'b'},"\n";
 
-
-=head2 Mixed Lists
+=head3 Mixed Lists
 
     # The zero in line below says its to be a mixed list
     my $list = $k->listof(40,0); # mixed list 40 elements
@@ -1612,7 +1611,7 @@ type for the array.  Only simple types are allowed at the moment.
 =cut
 
 package Kx::LIST;
-
+$Kx::LIST::VERSION = '0.042';
 use 5.008;
 use strict;
 use warnings;
@@ -1968,7 +1967,7 @@ package Kx::HASH;
 #####################################################################
 #                           K Hash package                          #
 #####################################################################
-
+$Kx::HASH::VERSION = '0.042';
 =head1 Kx::HASH
 
 You may wish to tie a Perl hash to a Kdb+ variable. Well, you can do
@@ -2237,9 +2236,9 @@ __END__
 
 =head1 SEE ALSO
 
-http://kx.com
+L<http://kx.com>
 
-http://code.kx.com
+L<http://code.kx.com>
 
 See the test code under the 't' directory of this module for more details
 on how to call each method.
@@ -2250,11 +2249,11 @@ on how to call each method.
 
 =item *
 
-Mark Pfeiffer, <markpf@mlp-consulting.com.au>
+Mark Pfeiffer <markpf@mlp-consulting.com.au>
 
 =item *
 
-Stephan Loyd, <stephanloyd9@gmail.com>
+Stephan Loyd <stephanloyd9@gmail.com>
 
 =back
 
